const base = require('./webpack.base.conf');
const serverBase = require('./webpack.server.conf')();
const argv = require('node-args');
const webpack = require("webpack");
const WebpackDevServer = require("webpack-dev-server");
const Dashboard = require('webpack-dashboard');
const DashboardPlugin = require('webpack-dashboard/plugin');
const notifier = require('node-notifier');
const opn = require('opn');
const fs = require('fs-extra');
const ora = require('ora');
const path = require('path');
const spinner = ora('   webpack配置检查完成准备启动服务');
const port = argv.p || 3001;

const main = o => {
	
	base.entry[`welcome/main`] = path.resolve(__dirname,'../pages/welcome') + '/main.js';

	base.output.publicPath = `//127.0.0.1:${port}/dest/dev/` //给require.ensure用

	base.module.rules.push({
				test: /\.(png|jpg|gif|svg)$/,
				loader: 'file-loader',
				query: {
					limit: 10000,
					name: 'bAssets/images/[name].[hash:7].[ext]', // ?[hash]
					publicPath: `http://127.0.0.1:${port}/dest/dev/`
				}
			});

	base.plugins.push(new webpack.HotModuleReplacementPlugin());

	if ( argv.m ) {
		var dashboard = new Dashboard();
		base.plugins.push(new DashboardPlugin(dashboard.setData));
	}

	console.log('\n');
	spinner.start();

	base.entry = Object.assign(base.entry , o.entry);

	const server = new WebpackDevServer(webpack(base), serverBase);

	const servers = server.listen( port , "localhost");

	servers.on('listening',function () {

		setTimeout(function () {
			spinner.stop();
			if ( o.openBrowser !== false ) {
				opn(`http://127.0.0.1:${ port }/pages/welcome/index.html`,{app: ['google chrome', '--incognito']});
			}
			notifier.notify({
				'title': '提示',
				'message': '\nwebpack:服务启动成功\n'
			});
		},2000);
	});

	servers.on('error' , function () {
		notifier.notify({
				'title': '提示',
				'message': '\nwebpack:服务启动失败,请检查原因\n'
		});
	});	
};

module.exports = o => {
	main.call(this,o);
}