const base = require('./webpack.base.conf');
const argv = require('node-args');
const webpack = require("webpack");
const WebpackDevServer = require("webpack-dev-server");
const notifier = require('node-notifier');
const fs = require('fs-extra');
const colors = require('colors');
const ora = require('ora');
const port = argv.p || 3001;
const path = require('path');

const main = o => {
	const spinner = ora( 'building for production...\n' );
	base.plugins.push(new webpack.DefinePlugin({
			'process.env': {
				NODE_ENV: '"production"'
			}
		}),
		new webpack.optimize.UglifyJsPlugin({
			sourceMap: false,
			compress: {
				warnings: false
			}
		})
	);

	base.entry = Object.assign(base.entry , o.entry);

	base.output.path = path.resolve(process.cwd() , `dest/${o.version}`);
	
	base.output.publicPath = `${o.staticSite}/dest/${o.version}/`; //修改require.ensure用

	base.module.rules.push({
			test: /\.(png|jpg|gif|svg)$/,
			loader: 'file-loader',
			query: {
				limit: 10000,
				name: 'bAssets/images/[name].[hash:7].[ext]', // ?[hash]
				publicPath:`${o.staticSite}/dest/${o.version}/`
			}
		});

	console.log('\n');
	spinner.start();
	
	const compiler = webpack(base);
	fs.remove('./dest').then(() => {
		compiler.run( (err, stats) => {
			if ( err ) {
				console.error(err);
				return process.exit(1);
			}
			if ( stats.hasErrors() ) {
				console.error('  webpack构建错误 \n');
				return process.exit(1);
			}
			spinner.stop();
			console.log(colors.green('  webpack构建成功 \n'));
		});
	}).catch((err)=>{
		if (err) return console.error(err)
	});
};

module.exports = o => {
	main.call(this,o)
}
